[PATCH v1 1/1] powerpc/papr_scm: Properly handle UUID types and API

Andy Shevchenko andriy.shevchenko at linux.intel.com
Thu Apr 15 23:46:37 AEST 2021


Parse to and export from UUID own type, before dereferencing.
This also fixes wrong comment (Little Endian UUID is something else)
and should fix Sparse warnings about assigning strict types to POD.

Fixes: 43001c52b603 ("powerpc/papr_scm: Use ibm,unit-guid as the iset cookie")
Fixes: 259a948c4ba1 ("powerpc/pseries/scm: Use a specific endian format for storing uuid from the device tree")
Cc: Oliver O'Halloran <oohall at gmail.com>
Cc: Aneesh Kumar K.V <aneesh.kumar at linux.ibm.com>
Signed-off-by: Andy Shevchenko <andriy.shevchenko at linux.intel.com>
---
Not tested
 arch/powerpc/platforms/pseries/papr_scm.c | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)

diff --git a/arch/powerpc/platforms/pseries/papr_scm.c b/arch/powerpc/platforms/pseries/papr_scm.c
index ae6f5d80d5ce..4366e1902890 100644
--- a/arch/powerpc/platforms/pseries/papr_scm.c
+++ b/arch/powerpc/platforms/pseries/papr_scm.c
@@ -1085,8 +1085,9 @@ static int papr_scm_probe(struct platform_device *pdev)
 	u32 drc_index, metadata_size;
 	u64 blocks, block_size;
 	struct papr_scm_priv *p;
+	u8 uuid_raw[UUID_SIZE];
 	const char *uuid_str;
-	u64 uuid[2];
+	uuid_t uuid;
 	int rc;
 
 	/* check we have all the required DT properties */
@@ -1129,16 +1130,18 @@ static int papr_scm_probe(struct platform_device *pdev)
 	p->hcall_flush_required = of_property_read_bool(dn, "ibm,hcall-flush-required");
 
 	/* We just need to ensure that set cookies are unique across */
-	uuid_parse(uuid_str, (uuid_t *) uuid);
+	uuid_parse(uuid_str, &uuid);
+
 	/*
 	 * cookie1 and cookie2 are not really little endian
 	 * we store a little endian representation of the
 	 * uuid str so that we can compare this with the label
 	 * area cookie irrespective of the endian config with which
 	 * the kernel is built.
 	 */
-	p->nd_set.cookie1 = cpu_to_le64(uuid[0]);
-	p->nd_set.cookie2 = cpu_to_le64(uuid[1]);
+	export_uuid(uuid_raw, &uuid);
+	p->nd_set.cookie1 = get_unaligned_le64(&uuid_raw[0]);
+	p->nd_set.cookie2 = get_unaligned_le64(&uuid_raw[8]);
 
 	/* might be zero */
 	p->metadata_size = metadata_size;
@@ -1129,16 +1130,18 @@ static int papr_scm_probe(struct platform_device *pdev)
 	/*
 	 * cookie1 and cookie2 are not really little endian
-	 * we store a little endian representation of the
+	 * we store a raw buffer representation of the
 	 * uuid str so that we can compare this with the label
 	 * area cookie irrespective of the endian config with which
-- 
2.30.2



More information about the Linuxppc-dev mailing list